yakumo.keystone.v2

Package yakumo :: Package keystone :: Package v2 |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.keystone.v2

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Sub client class for Identity V2 API
    18  """
    19
    20  from . import endpoint
    21  from . import project
    22  from . import role
    23  from . import service
    24  from . import user
    25
    26
    27 -class Client(object):
    28
    29 -    def __init__(self, client, **kwargs):
    30          self.endpoint = endpoint.Manager(client, **kwargs)
    31          self.project = project.Manager(client, **kwargs)
    32          self.role = role.Manager(client, **kwargs)
    33          self.service = service.Manager(client, **kwargs)
    34          self.user = user.Manager(client, **kwargs)
    35
    36          client.endpoint = self.endpoint
    37          client.project = self.project
    38          client.role = self.role
    39          client.service = self.service
    40          client.user = self.user
    41